@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2015 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -54,12 +54,7 @@ public:
     virtual void maybeReadVirginBody() = 0;
 
     /// abnormal transaction termination; reason is for debugging only
-    virtual void abortAll(const char *reason) = 0;
-
-    /// abnormal data transfer termination
-    /// \retval true the transaction will be terminated (abortAll called)
-    /// \retval false the transaction will survive
-    virtual bool abortOnData(const char *reason);
+    virtual void abortTransaction(const char *reason) = 0;
 
     /// a hack to reach HttpStateData::orignal_request
     virtual  HttpRequest *originalRequest();
@@ -104,9 +99,7 @@ protected:
     virtual void sentRequestBody(const CommIoCbParams &io) = 0;
     virtual void doneSendingRequestBody() = 0;
 
-    /// Use this to end communication with the server. The call cancels our
-    /// closure handler and tells FwdState to forget about the connection.
-    virtual void closeServer() = 0;
+    virtual void closeServer() = 0;            /**< end communication with the server */
     virtual bool doneWithServer() const = 0;   /**< did we end communication? */
     /// whether we may receive more virgin response body bytes
     virtual bool mayReadVirginReplyBody() const = 0;
@@ -131,7 +124,6 @@ protected:
     void handleAdaptationCompleted();
     void handleAdaptationBlocked(const Adaptation::Answer &answer);
     void handleAdaptationAborted(bool bypassable = false);
-    bool handledEarlyAdaptationAbort();
 
     /// called by StoreEntry when it has more buffer space available
     void resumeBodyStorage();
@@ -178,10 +170,6 @@ protected:
 #endif
     bool receivedWholeRequestBody; ///< handleRequestBodyProductionEnded called
 
-    /// whether we should not be talking to FwdState; XXX: clear fwd instead
-    /// points to a string literal which is used only for debugging
-    const char *doneWithFwd;
-
 private:
     void sendBodyIsTooLargeError();
     void maybePurgeOthers();
